bayespy.utils.misc.TestCase
===========================

.. currentmodule:: bayespy.utils.misc

.. autoclass:: TestCase

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~TestCase.__init__
      ~TestCase.addCleanup
      ~TestCase.addTypeEqualityFunc
      ~TestCase.assertAllClose
      ~TestCase.assertAlmostEqual
      ~TestCase.assertAlmostEquals
      ~TestCase.assertArrayEqual
      ~TestCase.assertCountEqual
      ~TestCase.assertDictContainsSubset
      ~TestCase.assertDictEqual
      ~TestCase.assertEqual
      ~TestCase.assertEquals
      ~TestCase.assertFalse
      ~TestCase.assertGreater
      ~TestCase.assertGreaterEqual
      ~TestCase.assertIn
      ~TestCase.assertIs
      ~TestCase.assertIsInstance
      ~TestCase.assertIsNone
      ~TestCase.assertIsNot
      ~TestCase.assertIsNotNone
      ~TestCase.assertLess
      ~TestCase.assertLessEqual
      ~TestCase.assertListEqual
      ~TestCase.assertLogs
      ~TestCase.assertMessage
      ~TestCase.assertMessageToChild
      ~TestCase.assertMultiLineEqual
      ~TestCase.assertNotAlmostEqual
      ~TestCase.assertNotAlmostEquals
      ~TestCase.assertNotEqual
      ~TestCase.assertNotEquals
      ~TestCase.assertNotIn
      ~TestCase.assertNotIsInstance
      ~TestCase.assertNotRegex
      ~TestCase.assertRaises
      ~TestCase.assertRaisesRegex
      ~TestCase.assertRaisesRegexp
      ~TestCase.assertRegex
      ~TestCase.assertRegexpMatches
      ~TestCase.assertSequenceEqual
      ~TestCase.assertSetEqual
      ~TestCase.assertTrue
      ~TestCase.assertTupleEqual
      ~TestCase.assertWarns
      ~TestCase.assertWarnsRegex
      ~TestCase.assert_
      ~TestCase.countTestCases
      ~TestCase.debug
      ~TestCase.defaultTestResult
      ~TestCase.doCleanups
      ~TestCase.fail
      ~TestCase.failIf
      ~TestCase.failIfAlmostEqual
      ~TestCase.failIfEqual
      ~TestCase.failUnless
      ~TestCase.failUnlessAlmostEqual
      ~TestCase.failUnlessEqual
      ~TestCase.failUnlessRaises
      ~TestCase.id
      ~TestCase.run
      ~TestCase.setUp
      ~TestCase.setUpClass
      ~TestCase.shortDescription
      ~TestCase.skipTest
      ~TestCase.subTest
      ~TestCase.tearDown
      ~TestCase.tearDownClass
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~TestCase.longMessage
      ~TestCase.maxDiff
   
   